[![PyPI](https://img.shields.io/pypi/v/virt-tools?style=plastic)](https://pypi.org/project/virt-tools/)


# FABRIC TESTBED LibVert ToolsCLI

## Overview
This package supports User facing APIs as well as CLI.
- Cpu: vCPU management for the VMs
- Numa: Numa management for the VMs
